%% Script to illustrate the use of objects in MATLAB
%
clear all
clc

%% Set the number of observations used
n = 100;

%% Generate data from an AR(1) model

% Create two instances of an AR(1) model object
AR1_1 = AR1();
AR1_2 = AR1();

% Set a different parameter value for each object and one lag
AR1_1.setPars(0.5);
AR1_2.setPars(1);

% Generate a data series from each of the models using a set of innovations
eps  = randn(n,1);
dat1 = AR1_1.generate(eps);
dat2 = AR1_2.generate(eps);

%% Estimate the parameter in an AR(1) model using data from a data objects

% Introduce data into AR objects
AR1_1.setData(dat1);
AR1_2.setData(dat2);

% Estimate the parameters
AR1_1.estimate();
AR1_2.estimate();

disp('AR1_1 coefficient');
disp(AR1_1.getPars());

disp('AR1_2 coefficient');
disp(AR1_2.getPars());

%% Simulate the distributions of rho1 and rho2

% Create two instances of the model, one estimation model and one dgp
dgpAR = AR1();
dgpAR.setPars(1);
estAR = AR1();

% Use the simulation object to generate the empirical distribution
Sim1 = Simulation(estAR,dgpAR,10000);
Sim1.simParDist();

%% Generate data from MA object

% Create MA objects
MA = MA1();

% Set MA coefficient
MA.setPars(0.5);

% Generate data
dat3 = MA.generate(eps);

% Estimate MA
MA.setData(dat3);
MA.estimate();

disp('MA1 coefficient')
disp(MA.getPars())

%% Simulate the distribution of Alpha1
dgpMA = MA1();
estMA = MA1();
dgpMA.setPars(0.5);
estMA.setPars(0.5);

Sim2 = Simulation(estMA,dgpMA,10000);
Sim2.simParDist();

% matlabpool close;
