classdef MA1 < Model
    %UNTITLED Summary of this class goes here
    %   Detailed explanation goes here
    
    properties
        Name        % String name for model class
        Dimension   % Number of variables in model
        NumPars     % Number of parameters in model
        NumFreePars % Number of freely varying parameters
        LHS         % Left hand side variable
        Nobs        % Number of observations
    end
    
    properties (Access = private)
        Pars
        Loglikelihood
    end
    
    methods
        function this = MA1()
            this.Name      = 'Moving Average of order 1';
            this.Dimension = 1;
            this.NumPars   = 1;
        end
        function estimate(this)
            X   = this.LHS;
            T   = this.Nobs;
            vP  = this.getVectorPars();           
            
            % Create annonymous function
            ll = @(vp) this.loglik(vp,X,T);
            
            opt = optimset('Display','off',...
                           'LargeScale','off');
            
            [outp,outll] = fminunc(ll,vP,opt);
            
            this.setPars(outp);
            this.setLoglik(-outll);
            
            % Alternatively one can write:
%             this.Pars = outp;
%             this.Loglikelihood = outll;
        end
        function [data] = generate(this,innovations)
            T     = size(innovations,1);
            eps   = innovations;
            alpha = this.Pars;
            X     = zeros(T,1);
            for i = 1:T-1
                X(i+1) = eps(i+1)+alpha*eps(i);
            end
            X    = X(2:end,1);
            data = X;
        end
    end
    
    % I/O methods
    methods
        function setPars(this,par)
            this.Pars = par;
        end
        function setLoglik(this,ll)
            this.Loglikelihood = ll;
        end
        function setData(this,X)
            this.LHS  = X;
            this.Nobs = size(X,1)-1; 
        end
        function [pars] = getPars(this)
            pars = this.Pars;
        end
        function [vP] = getVectorPars(this)
            vP = this.Pars;
        end
        function [vP] = getVectorFreePars(this)
            vP = this.Pars;
        end
    end
    
    methods(Static)
       function [ll] = loglik(vP,X,T)
            alpha  = vP;
            eps    = zeros(T+1,1);
            ll     = zeros(T,1);
            for i = 2:T+1
                eps(i) = X(i)-alpha*eps(i-1); 
                ll(i)  = 0.5*log(2*3.14159265) + 0.5*(eps(i)^2);
            end
            ll = sum(ll,1);
        end
    end
    
end

